@@ -1,6 +1,6 @@
 /* exception.h
  *
- * $Id: exception.h,v 1.24 2000/11/26 23:25:51 nisse Exp $ */
+ * $Id: exception.h,v 1.26 2002/06/27 17:08:20 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -75,10 +75,6 @@ void exception_raise(struct exception_handler *e,
 
 /* Exception types. */
 
-/* Used in places where no real exception is defined yet.
- * Never handled. */
-#define EXC_DUMMY 0
-
 /* FIXME: This is an inappropriate name, as this exception type is
  * used for all events that should result in a disconnect message. */
 
@@ -160,7 +156,6 @@ void exception_raise(struct exception_handler *e,
 
 extern struct exception_handler default_exception_handler;
 extern struct exception_handler ignore_exception_handler;
-extern struct exception dummy_exception;
 
 /* GABA:
    (class
@@ -179,7 +174,7 @@ make_report_exception_info(UINT32 mask, UINT32 value,
 { STATIC_HEADER, m, v, p }
 
 struct exception_handler *
-make_report_exception_handler(struct report_exception_info *info,
+make_report_exception_handler(const struct report_exception_info *info,
 			      struct exception_handler *parent,
 			      const char *context);
 
