@@ -1,6 +1,6 @@
 /* io_commands.c
  *
- * $Id: io_commands.c,v 1.53 2002/05/29 22:51:11 _cvs_pont Exp $
+ * $Id: io_commands.c,v 1.54 2002/07/03 12:46:34 _cvs_pont Exp $
  */
 
 /* lsh, an implementation of the ssh protocol
@@ -373,13 +373,20 @@ DEFINE_COMMAND(connect_local_command)
       struct exception_handler *e UNUSED)
 {
   CAST(local_info, info, a);
-
-  io_connect_local(info,
-		   make_connect_continuation(NULL, c),
-		   e);
+  
+  static struct exception gateway_exception =
+    STATIC_EXCEPTION(EXC_IO_CONNECT, "no usable gateway socket found");
+  
+  struct lsh_fd *fd = io_connect_local(info,
+				       make_connect_continuation(NULL, c),
+				       e);
+  
+  if (!fd)
+    EXCEPTION_RAISE(e, &gateway_exception);
 }
 
 
+
 /* Takes a listen_value as argument, logs the peer address, and
  * returns the fd object. */
 
