@@ -1,6 +1,6 @@
 /* server.c
  *
- * $Id: server.c,v 1.67 2001/10/03 15:58:27 nisse Exp $ */
+ * $Id: server.c,v 1.69 2002/03/13 16:01:31 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -28,7 +28,6 @@
 #include "compress.h"
 #include "connection.h"
 #include "debug.h"
-#include "disconnect.h"
 #include "format.h"
 #include "keyexchange.h"
 #include "read_line.h"
@@ -245,6 +244,7 @@ read_host_key(const char *file,
               make_keypair(ATOM_SPKI_SIGN_DSS, spki_public, s));
       break;
 
+    case ATOM_RSA_PKCS1:
     case ATOM_RSA_PKCS1_SHA1:
       add_key(keys,
               make_keypair(ATOM_SSH_RSA, PUBLIC_KEY(v), s));
