@@ -2,7 +2,7 @@
  *
  * user authorization database
  *
- * $Id: server_authorization.c,v 1.16 2001/04/08 15:15:14 nisse Exp $ */
+ * $Id: server_authorization.c,v 1.18 2002/01/21 00:05:04 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -27,7 +27,7 @@
 
 #include "dsa.h"
 #include "format.h"
-#include "rsa.h"
+#include "publickey_crypto.h"
 #include "server_userauth.h"
 #include "sexp.h"
 #include "spki.h"
@@ -47,7 +47,7 @@
      (vars
        (index_name string)
        ;; (signalgo object signature_algorithm)
-       (hashalgo object hash_algorithm)))
+       (hashalgo const object hash_algorithm)))
 */
 
 static struct verifier *
@@ -103,7 +103,7 @@ do_key_lookup(struct lookup_verifier *c,
 struct lookup_verifier *
 make_authorization_db(struct lsh_string *index_name, 
 		      /* struct signature_algorithm *s, */
-		      struct hash_algorithm *h)
+		      const struct hash_algorithm *h)
 {
   NEW(authorization_db, res);
 
