@@ -1,6 +1,6 @@
 /* tcpforward_commands.c
  *
- * $Id: tcpforward_commands.c,v 1.40 2001/09/28 21:54:10 nisse Exp $
+ * $Id: tcpforward_commands.c,v 1.41 2002/06/27 17:11:16 nisse Exp $
  */
 
 /* lsh, an implementation of the ssh protocol
@@ -75,8 +75,9 @@ static struct catch_report_collect catch_channel_open;
 
 #include "tcpforward_commands.c.x"
 
-static struct report_exception_info open_tcpip_report =
-STATIC_REPORT_EXCEPTION_INFO(EXC_ALL, EXC_CHANNEL_OPEN, "Failed to open tcpip channel");
+static const struct report_exception_info open_tcpip_report =
+STATIC_REPORT_EXCEPTION_INFO(EXC_ALL, EXC_CHANNEL_OPEN,
+			     "Failed to open tcpip channel");
 
 static struct catch_report_collect catch_channel_open
 = STATIC_CATCH_REPORT(&open_tcpip_report);
