@@ -2,7 +2,7 @@
  *
  * User-related functions on UN*X
  *
- * $Id: unix_user.c,v 1.48 2002/03/17 23:24:28 nisse Exp $
+ * $Id: unix_user.c,v 1.52 2002/07/02 19:42:36 nisse Exp $
  */
 
 /* lsh, an implementation of the ssh protocol
@@ -253,8 +253,9 @@ do_verify_password(struct lsh_user *s,
       return;
     }
   
-  /* NOTE: Check for accounts with empty passwords. */
-  if (!user->passwd || (user->passwd->length < 2) )
+  /* NOTE: Check for accounts with empty passwords, or generally short
+   * passwd fields like "NP" or "x". */
+  if (!user->passwd || (user->passwd->length < 5) )
     {
       static const struct exception no_passwd
 	= STATIC_EXCEPTION(EXC_USERAUTH, "No password in passwd db.");
@@ -748,7 +749,11 @@ do_spawn(struct lsh_user *u,
 
       safe_close(info->in[0]);  safe_close(info->in[1]);
       safe_close(info->out[0]); safe_close(info->out[1]);
-      safe_close(info->err[0]); safe_close(info->err[1]);
+      safe_close(info->err[0]);
+      /* Allow the client's stdout and stderr to be the same fd, e.g.
+       * both /dev/null. */
+      if (info->err[1] != info->out[1])
+	safe_close(info->err[1]);
 
       return NULL;
     }
@@ -764,7 +769,11 @@ do_spawn(struct lsh_user *u,
       /* Close the child's fd:s, except ones that are -1 */
       safe_close(info->in[0]);
       safe_close(info->out[1]);
-      safe_close(info->err[1]);
+
+      /* Allow the client's stdout and stderr to be the same fd, e.g.
+       * both /dev/null. */
+      if (info->err[1] != info->out[1])
+	safe_close(info->err[1]);
 
       safe_close(sync[1]);
 
@@ -774,7 +783,7 @@ do_spawn(struct lsh_user *u,
        * tty, after which it should close its end of the
        * syncronization pipe, and our read will return 0.
        *
-       * We need the syncronizatino only if we're actually using a
+       * We need the syncronization only if we're actually using a
        * pty, but for simplicity, we do it every time. */
       
       do
@@ -863,7 +872,11 @@ do_spawn(struct lsh_user *u,
       safe_close(info->out[0]);
       safe_close(info->out[1]);
       safe_close(info->err[0]);
-      safe_close(info->err[1]);
+      /* Allow the client's stdout and stderr to be the same fd, e.g.
+       * both /dev/null. */
+      if (info->err[1] != info->out[1])
+	safe_close(info->err[1]);
+
       safe_close(tty);
       
       exec_shell(user, info);
@@ -922,16 +935,42 @@ make_unix_user(struct lsh_string *name,
 */
 
 
-/* NOTE: Calls functions using the disgusting convention of returning
- * pointers to static buffers. */
-
-/* This method filters out accounts that are known to be disabled
- * (i.e. root, or shadow style expiration). However, it may still
- * return some disabled accounts.
+/* It's somewhat tricky to determine when accounts are disabled. To be
+ * safe, it is recommended that all disabled accounts have a harmless
+ * login-shell, like /bin/false.
  *
- * An account that is disabled in /etc/passwd should have a value for
- * the login shell that prevents login; replacing the passwd field
- * only doesn't prevent login using publickey authentication. */
+ * We return NULL for disabled accounts, according to the following
+ * rules:
+ *
+ * If our uid is non-zero, i.e. we're not running as root, then an
+ * account is considered valid if and only if it's uid matches the
+ * server's. We never try checking the shadow record.
+ *
+ * If we're running as root, first check the passwd record.
+ *
+ * o If the uid is zero, consider the account disabled. --root-login
+ *   omits this check.
+ *
+ * o If the passwd equals "x", look up the shadow record, check
+ *   expiration etc, and replace the passwd value with the one from the
+ *   shadow record. If there's no shadow record, consider the account
+ *   disabled.
+ *
+ * o If the passwd field is empty, consider the account disabled (we
+ *   usually don't want remote logins on pasword-less accounts). We may
+ *   need to make this check optional, though.
+ *
+ * o If the passwd entry starts with a "*" and is longer than one
+ *   character, consider the account disabled. (Other bogus values like
+ *   "NP" means that the account is enabled, only password login is
+ *   disabled)
+ *
+ * o Otherwise, the account is active, and a user record is returned.
+ *
+ * FIXME: What about systems that uses a single "*" to disable
+ * accounts?
+ */
+
 static struct lsh_user *
 do_lookup_user(struct user_db *s,
 	       struct lsh_string *name, int free)
@@ -942,24 +981,57 @@ do_lookup_user(struct user_db *s,
   const char *home;
   const char *shell;
   const char *cname = lsh_get_cstring(name);
-  
+  char *crypted;
+  uid_t me;
+
   if (!cname)
     {
       if (free)
 	lsh_string_free(name);
       return NULL;
     }
+
+  me = getuid();
+  passwd = getpwnam(cname);
+
+  if (!passwd)
+    {
+    fail:
+      if (free)
+	lsh_string_free(name);
+      return NULL;
+    }
+
+  crypted = passwd->pw_passwd;
   
-  if ((passwd = getpwnam(cname))
+  if (!crypted || !*crypted)
+    /* Ignore accounts with empty passwords. */
+    goto fail;
+
+  if (me)
+    {
+      /* We're not root. Disable all accounts but our own. */
+      if (passwd->pw_uid != me)
+	goto fail;
+
+      /* NOTE: If we are running as the uid of the user, it seems like
+       * a good idea to let the HOME environment variable override the
+       * passwd-database. */
+      home = getenv("HOME");
+      if (!home)
+	home = passwd->pw_dir;
+    }
+  else
+    {
       /* Check for root login */
-      && (passwd->pw_uid || self->allow_root))
-    {      
-      char *crypted;
-  
+      if (!passwd->pw_uid && !self->allow_root)
+	goto fail;
+      
 #if HAVE_GETSPNAM
-      /* FIXME: What's the most portable way to test for shadow passwords?
-       * A single character in the passwd field should cover most variants. */
-      if (passwd->pw_passwd && (strlen(passwd->pw_passwd) == 1))
+      /* FIXME: What's the most portable way to test for shadow
+       * passwords? For now, we look up shadow database if and only if
+       * the passwd field equals "x". */
+      if (!strcmp(crypted, "x"))
 	{
 	  struct spwd *shadowpwd;
 
@@ -1010,39 +1082,32 @@ do_lookup_user(struct user_db *s,
 
 	  crypted = shadowpwd->sp_pwdp;
 	}
-      else
 #endif /* HAVE_GETSPNAM */
-	crypted = passwd->pw_passwd;
+      /* Check again for empty passwd field (as it may have been
+       * replaced by the shadow one). */
+      if (!crypted || !*crypted)
+	goto fail;
 
-      /* NOTE: If we are running as the uid of the user, it seems
-       * like a good idea to let the HOME environment variable
-       * override the passwd-database. */
-
-      if (! (passwd->pw_uid
-	     && (passwd->pw_uid == getuid())
-	     && (home = getenv("HOME"))))
-	home = passwd->pw_dir;
-
-      if (self->login_shell)
-	/* Override the passwd database */
-	shell = self->login_shell;
-      else
-	/* Default login shell is /bin/sh */
-	shell = passwd->pw_shell ? passwd->pw_shell : "/bin/sh";
+      /* A passwd field of more than one character, which starts with a star,
+       * indicates a disabled account. */
+      if ( (crypted[0] == '*') && crypted[1])
+	goto fail;
       
-      return make_unix_user(free ? name : lsh_string_dup(name), 
-			    passwd->pw_uid, passwd->pw_gid,
-			    self,
-			    crypted,
-			    home, shell);
+      home = passwd->pw_dir;
     }
+  
+  if (self->login_shell)
+    /* Override the passwd database */
+    shell = self->login_shell;
   else
-    {
-    fail:
-      if (free)
-	lsh_string_free(name);
-      return NULL;
-    }
+    /* Default login shell is /bin/sh */
+    shell = passwd->pw_shell ? passwd->pw_shell : "/bin/sh";
+      
+  return make_unix_user(free ? name : lsh_string_dup(name), 
+			passwd->pw_uid, passwd->pw_gid,
+			self,
+			crypted,
+			home, shell);
 }
 
 struct user_db *
